@@ -8,7 +8,7 @@ from cookiecutter import main, utils
 
 
 @pytest.fixture(scope='function')
-def remove_additional_dirs(request):
+def remove_additional_dirs():
     """Remove special directories which are created during the tests."""
     yield
     if os.path.isdir('fake-project'):
@@ -18,11 +18,11 @@ def remove_additional_dirs(request):
 
 
 @pytest.mark.usefixtures('clean_system', 'remove_additional_dirs')
-def test_cookiecutter_local_with_input(monkeypatch):
+def test_cookiecutter_local_with_input(monkeypatch) -> None:
     """Verify simple cookiecutter run results, without extra_context provided."""
     monkeypatch.setattr(
         'cookiecutter.prompt.read_user_variable',
-        lambda var, default, prompts, prefix: default,
+        lambda _var, default, _prompts, _prefix: default,
     )
     main.cookiecutter('tests/fake-repo-pre/', no_input=False)
     assert os.path.isdir('tests/fake-repo-pre/{{cookiecutter.repo_name}}')
@@ -33,11 +33,11 @@ def test_cookiecutter_local_with_input(monkeypatch):
 
 
 @pytest.mark.usefixtures('clean_system', 'remove_additional_dirs')
-def test_cookiecutter_input_extra_context(monkeypatch):
+def test_cookiecutter_input_extra_context(monkeypatch) -> None:
     """Verify simple cookiecutter run results, with extra_context provided."""
     monkeypatch.setattr(
         'cookiecutter.prompt.read_user_variable',
-        lambda var, default, prompts, prefix: default,
+        lambda _var, default, _prompts, _prefix: default,
     )
     main.cookiecutter(
         'tests/fake-repo-pre',
