@@ -1,16 +1,21 @@
 """Verify generate context behaviour and context overwrite priorities."""
 
+from __future__ import annotations
+
 import os
 import re
 from collections import OrderedDict
+from collections.abc import Iterator
+from typing import Any
 
 import pytest
 
 from cookiecutter import generate
 from cookiecutter.exceptions import ContextDecodingException
+from cookiecutter.prompt import YesNoPrompt
 
 
-def context_data():
+def context_data() -> Iterator[tuple[dict[str, Any], dict[str, Any]]]:
     """Generate pytest parametrization variables for test.
 
     Return ('input_params, expected_context') tuples.
@@ -53,13 +58,13 @@ def context_data():
 
 @pytest.mark.usefixtures('clean_system')
 @pytest.mark.parametrize('input_params, expected_context', context_data())
-def test_generate_context(input_params, expected_context):
+def test_generate_context(input_params, expected_context) -> None:
     """Verify input contexts combinations result in expected content on output."""
     assert generate.generate_context(**input_params) == expected_context
 
 
 @pytest.mark.usefixtures('clean_system')
-def test_generate_context_with_json_decoding_error():
+def test_generate_context_with_json_decoding_error() -> None:
     """Verify malformed JSON file generates expected error output."""
     with pytest.raises(ContextDecodingException) as excinfo:
         generate.generate_context('tests/test-generate-context/invalid-syntax.json')
@@ -74,7 +79,7 @@ def test_generate_context_with_json_decoding_error():
     assert path in str(excinfo.value)
 
 
-def test_default_context_replacement_in_generate_context():
+def test_default_context_replacement_in_generate_context() -> None:
     """Verify default content settings are correctly replaced by template settings.
 
     Make sure that the default for list variables of `orientation` is based on
@@ -109,7 +114,7 @@ def test_default_context_replacement_in_generate_context():
     assert generated_context == expected_context
 
 
-def test_generate_context_decodes_non_ascii_chars():
+def test_generate_context_decodes_non_ascii_chars() -> None:
     """Verify `generate_context` correctly decodes non-ascii chars."""
     expected_context = {
         'non_ascii': OrderedDict(
@@ -148,7 +153,7 @@ def template_context():
     )
 
 
-def test_apply_overwrites_does_include_unused_variables(template_context):
+def test_apply_overwrites_does_include_unused_variables(template_context) -> None:
     """Verify `apply_overwrites_to_context` skips variables that are not in context."""
     generate.apply_overwrites_to_context(
         context=template_context, overwrite_context={'not in template': 'foobar'}
@@ -157,7 +162,7 @@ def test_apply_overwrites_does_include_unused_variables(template_context):
     assert 'not in template' not in template_context
 
 
-def test_apply_overwrites_sets_non_list_value(template_context):
+def test_apply_overwrites_sets_non_list_value(template_context) -> None:
     """Verify `apply_overwrites_to_context` work with string variables."""
     generate.apply_overwrites_to_context(
         context=template_context, overwrite_context={'repo_name': 'foobar'}
@@ -166,7 +171,7 @@ def test_apply_overwrites_sets_non_list_value(template_context):
     assert template_context['repo_name'] == 'foobar'
 
 
-def test_apply_overwrites_does_not_modify_choices_for_invalid_overwrite():
+def test_apply_overwrites_does_not_modify_choices_for_invalid_overwrite() -> None:
     """Verify variables overwrite for list if variable not in list ignored."""
     expected_context = {
         'choices_template': OrderedDict(
@@ -197,7 +202,7 @@ def test_apply_overwrites_does_not_modify_choices_for_invalid_overwrite():
     assert generated_context == expected_context
 
 
-def test_apply_overwrites_invalid_overwrite(template_context):
+def test_apply_overwrites_invalid_overwrite(template_context) -> None:
     """Verify variables overwrite for list if variable not in list not ignored."""
     with pytest.raises(ValueError):
         generate.apply_overwrites_to_context(
@@ -205,7 +210,7 @@ def test_apply_overwrites_invalid_overwrite(template_context):
         )
 
 
-def test_apply_overwrites_sets_multichoice_values(template_context):
+def test_apply_overwrites_sets_multichoice_values(template_context) -> None:
     """Verify variable overwrite for list given multiple valid values."""
     generate.apply_overwrites_to_context(
         context=template_context,
@@ -214,7 +219,7 @@ def test_apply_overwrites_sets_multichoice_values(template_context):
     assert template_context['deployment_regions'] == ['eu']
 
 
-def test_apply_overwrites_invalid_multichoice_values(template_context):
+def test_apply_overwrites_invalid_multichoice_values(template_context) -> None:
     """Verify variable overwrite for list given invalid list entries not ignored."""
     with pytest.raises(ValueError):
         generate.apply_overwrites_to_context(
@@ -223,7 +228,7 @@ def test_apply_overwrites_invalid_multichoice_values(template_context):
         )
 
 
-def test_apply_overwrites_error_additional_values(template_context):
+def test_apply_overwrites_error_additional_values(template_context) -> None:
     """Verify variable overwrite for list given additional entries not ignored."""
     with pytest.raises(ValueError):
         generate.apply_overwrites_to_context(
@@ -232,7 +237,7 @@ def test_apply_overwrites_error_additional_values(template_context):
         )
 
 
-def test_apply_overwrites_in_dictionaries(template_context):
+def test_apply_overwrites_in_dictionaries(template_context) -> None:
     """Verify variable overwrite for lists nested in dictionary variables."""
     generate.apply_overwrites_to_context(
         context=template_context,
@@ -242,7 +247,7 @@ def test_apply_overwrites_in_dictionaries(template_context):
     assert template_context['deployments']['prod'] == ['ap']
 
 
-def test_apply_overwrites_sets_default_for_choice_variable(template_context):
+def test_apply_overwrites_sets_default_for_choice_variable(template_context) -> None:
     """Verify overwritten list member became a default value."""
     generate.apply_overwrites_to_context(
         context=template_context, overwrite_context={'orientation': 'landscape'}
@@ -251,7 +256,7 @@ def test_apply_overwrites_sets_default_for_choice_variable(template_context):
     assert template_context['orientation'] == ['landscape', 'all', 'portrait']
 
 
-def test_apply_overwrites_in_nested_dict():
+def test_apply_overwrites_in_nested_dict() -> None:
     """Verify nested dict in default content settings are correctly replaced."""
     expected_context = {
         'nested_dict': OrderedDict(
@@ -293,7 +298,7 @@ def test_apply_overwrites_in_nested_dict():
     assert generated_context == expected_context
 
 
-def test_apply_overwrite_context_as_in_nested_dict_with_additional_values():
+def test_apply_overwrite_context_as_in_nested_dict_with_additional_values() -> None:
     """Verify nested dict in default content settings are correctly added.
 
     The `apply_overwrites_to_context` function should add the extra values to the dict.
@@ -309,7 +314,7 @@ def test_apply_overwrite_context_as_in_nested_dict_with_additional_values():
     assert context == expected
 
 
-def test_apply_overwrites_in_nested_dict_additional_values():
+def test_apply_overwrites_in_nested_dict_additional_values() -> None:
     """Verify nested dict in default content settings are correctly added."""
     expected_context = {
         'nested_dict_additional': OrderedDict(
@@ -362,3 +367,24 @@ def test_apply_overwrites_in_nested_dict_additional_values():
     )
 
     assert generated_context == expected_context
+
+
+@pytest.mark.parametrize(
+    "overwrite_value, expected",
+    [(bool_string, {'key': True}) for bool_string in YesNoPrompt.yes_choices]
+    + [(bool_string, {'key': False}) for bool_string in YesNoPrompt.no_choices],
+)
+def test_apply_overwrites_overwrite_value_as_boolean_string(overwrite_value, expected):
+    """Verify boolean conversion for valid overwrite values."""
+    context = {'key': not expected['key']}
+    overwrite_context = {'key': overwrite_value}
+    generate.apply_overwrites_to_context(context, overwrite_context)
+    assert context == expected
+
+
+def test_apply_overwrites_error_overwrite_value_as_boolean_string():
+    """Verify boolean conversion for invalid overwrite values."""
+    context = {'key': True}
+    overwrite_context = {'key': 'invalid'}
+    with pytest.raises(ValueError):
+        generate.apply_overwrites_to_context(context, overwrite_context)
