@@ -1,10 +1,13 @@
 """Tests for `cookiecutter.prompt` module."""
 
+from __future__ import annotations
+
 import json
 import platform
 import sys
 from collections import OrderedDict
 from pathlib import Path
+from typing import Any
 
 import click
 import pytest
@@ -13,7 +16,7 @@ from cookiecutter import environment, exceptions, prompt
 
 
 @pytest.fixture(autouse=True)
-def patch_readline_on_win(monkeypatch):
+def patch_readline_on_win(monkeypatch) -> None:
     """Fixture. Overwrite windows end of line to linux standard."""
     if 'windows' in platform.platform().lower():
         monkeypatch.setattr('sys.stdin.readline', lambda: '\n')
@@ -32,7 +35,7 @@ class TestRenderVariable:
             (None, None),
         ],
     )
-    def test_convert_to_str(self, mocker, raw_var, rendered_var):
+    def test_convert_to_str(self, mocker, raw_var, rendered_var) -> None:
         """Verify simple items correctly rendered to strings."""
         env = environment.StrictEnvironment()
         from_string = mocker.patch(
@@ -62,7 +65,7 @@ class TestRenderVariable:
             (['foo', '{{cookiecutter.project}}', None], ['foo', 'foobar', None]),
         ],
     )
-    def test_convert_to_str_complex_variables(self, raw_var, rendered_var):
+    def test_convert_to_str_complex_variables(self, raw_var, rendered_var) -> None:
         """Verify tree items correctly rendered."""
         env = environment.StrictEnvironment()
         context = {'project': 'foobar'}
@@ -82,11 +85,11 @@ class TestPrompt:
         ],
         ids=['ASCII default prompt/input', 'Unicode default prompt/input'],
     )
-    def test_prompt_for_config(self, monkeypatch, context):
+    def test_prompt_for_config(self, monkeypatch, context) -> None:
         """Verify `prompt_for_config` call `read_user_variable` on text request."""
         monkeypatch.setattr(
             'cookiecutter.prompt.read_user_variable',
-            lambda var, default, prompts, prefix: default,
+            lambda _var, default, _prompts, _prefix: default,
         )
 
         cookiecutter_dict = prompt.prompt_for_config(context)
@@ -109,19 +112,19 @@ class TestPrompt:
         ],
         ids=['ASCII default prompt/input'],
     )
-    def test_prompt_for_config_with_human_prompts(self, monkeypatch, context):
+    def test_prompt_for_config_with_human_prompts(self, monkeypatch, context) -> None:
         """Verify call `read_user_variable` on request when human-readable prompts."""
         monkeypatch.setattr(
             'cookiecutter.prompt.read_user_variable',
-            lambda var, default, prompts, prefix: default,
+            lambda _var, default, _prompts, _prefix: default,
         )
         monkeypatch.setattr(
             'cookiecutter.prompt.read_user_yes_no',
-            lambda var, default, prompts, prefix: default,
+            lambda _var, default, _prompts, _prefix: default,
         )
         monkeypatch.setattr(
             'cookiecutter.prompt.read_user_choice',
-            lambda var, default, prompts, prefix: default,
+            lambda _var, default, _prompts, _prefix: default,
         )
 
         cookiecutter_dict = prompt.prompt_for_config(context)
@@ -161,7 +164,7 @@ class TestPrompt:
             },
         ],
     )
-    def test_prompt_for_config_with_human_choices(self, monkeypatch, context):
+    def test_prompt_for_config_with_human_choices(self, context) -> None:
         """Test prompts when human-readable labels for user choices."""
         runner = click.testing.CliRunner()
         with runner.isolation(input="\n\n\n"):
@@ -169,18 +172,18 @@ class TestPrompt:
 
         assert dict(cookiecutter_dict) == {'full_name': 'Your Name', 'check': 'yes'}
 
-    def test_prompt_for_config_dict(self, monkeypatch):
+    def test_prompt_for_config_dict(self, monkeypatch) -> None:
         """Verify `prompt_for_config` call `read_user_variable` on dict request."""
         monkeypatch.setattr(
             'cookiecutter.prompt.read_user_dict',
-            lambda var, default, prompts, prefix: {"key": "value", "integer": 37},
+            lambda _var, _default, _prompts, _prefix: {"key": "value", "integer": 37},
         )
-        context = {'cookiecutter': {'details': {}}}
+        context: dict[str, Any] = {'cookiecutter': {'details': {}}}
 
         cookiecutter_dict = prompt.prompt_for_config(context)
         assert cookiecutter_dict == {'details': {'key': 'value', 'integer': 37}}
 
-    def test_should_render_dict(self):
+    def test_should_render_dict(self) -> None:
         """Verify template inside dictionary variable rendered."""
         context = {
             'cookiecutter': {
@@ -197,7 +200,7 @@ class TestPrompt:
             'details': {'Slartibartfast': 'Slartibartfast'},
         }
 
-    def test_should_render_deep_dict(self):
+    def test_should_render_deep_dict(self) -> None:
         """Verify nested structures like dict in dict, rendered correctly."""
         context = {
             'cookiecutter': {
@@ -242,7 +245,7 @@ class TestPrompt:
             },
         }
 
-    def test_should_render_deep_dict_with_human_prompts(self):
+    def test_should_render_deep_dict_with_human_prompts(self) -> None:
         """Verify dict rendered correctly when human-readable prompts."""
         context = {
             'cookiecutter': {
@@ -271,7 +274,7 @@ class TestPrompt:
             },
         }
 
-    def test_internal_use_no_human_prompts(self):
+    def test_internal_use_no_human_prompts(self) -> None:
         """Verify dict rendered correctly when human-readable prompts empty."""
         context = {
             'cookiecutter': {
@@ -284,11 +287,11 @@ class TestPrompt:
             'project_name': "Slartibartfast",
         }
 
-    def test_prompt_for_templated_config(self, monkeypatch):
+    def test_prompt_for_templated_config(self, monkeypatch) -> None:
         """Verify Jinja2 templating works in unicode prompts."""
         monkeypatch.setattr(
             'cookiecutter.prompt.read_user_variable',
-            lambda var, default, prompts, prefix: default,
+            lambda _var, default, _prompts, _prefix: default,
         )
         context = {
             'cookiecutter': OrderedDict(
@@ -309,11 +312,11 @@ class TestPrompt:
         cookiecutter_dict = prompt.prompt_for_config(context)
         assert cookiecutter_dict == exp_cookiecutter_dict
 
-    def test_dont_prompt_for_private_context_var(self, monkeypatch):
+    def test_dont_prompt_for_private_context_var(self, monkeypatch) -> None:
         """Verify `read_user_variable` not called for private context variables."""
         monkeypatch.setattr(
             'cookiecutter.prompt.read_user_variable',
-            lambda var, default: pytest.fail(
+            lambda _var, _default: pytest.fail(
                 'Should not try to read a response for private context var'
             ),
         )
@@ -321,7 +324,7 @@ class TestPrompt:
         cookiecutter_dict = prompt.prompt_for_config(context)
         assert cookiecutter_dict == {'_copy_without_render': ['*.html']}
 
-    def test_should_render_private_variables_with_two_underscores(self):
+    def test_should_render_private_variables_with_two_underscores(self) -> None:
         """Test rendering of private variables with two underscores.
 
         There are three cases:
@@ -358,7 +361,7 @@ class TestPrompt:
             ]
         )
 
-    def test_should_not_render_private_variables(self):
+    def test_should_not_render_private_variables(self) -> None:
         """Verify private(underscored) variables not rendered by `prompt_for_config`.
 
         Private variables designed to be raw, same as context input.
@@ -383,7 +386,7 @@ DEFAULT_PREFIX = '  [dim][1/1][/] '
 class TestReadUserChoice:
     """Class to unite choices prompt related tests."""
 
-    def test_should_invoke_read_user_choice(self, mocker):
+    def test_should_invoke_read_user_choice(self, mocker) -> None:
         """Verify correct function called for select(list) variables."""
         prompt_choice = mocker.patch(
             'cookiecutter.prompt.prompt_choice_for_config',
@@ -407,10 +410,10 @@ class TestReadUserChoice:
         )
         assert cookiecutter_dict == {'orientation': 'all'}
 
-    def test_should_invoke_read_user_variable(self, mocker):
+    def test_should_invoke_read_user_variable(self, mocker) -> None:
         """Verify correct function called for string input variables."""
         read_user_variable = mocker.patch('cookiecutter.prompt.read_user_variable')
-        read_user_variable.return_value = 'Audrey Roy'
+        read_user_variable.return_value = 'Audrey M. Roy Greenfeld'
 
         prompt_choice = mocker.patch('cookiecutter.prompt.prompt_choice_for_config')
 
@@ -425,9 +428,9 @@ class TestReadUserChoice:
         read_user_variable.assert_called_once_with(
             'full_name', 'Your Name', {}, DEFAULT_PREFIX
         )
-        assert cookiecutter_dict == {'full_name': 'Audrey Roy'}
+        assert cookiecutter_dict == {'full_name': 'Audrey M. Roy Greenfeld'}
 
-    def test_should_render_choices(self, mocker):
+    def test_should_render_choices(self, mocker) -> None:
         """Verify Jinja2 templating engine works inside choices variables."""
         read_user_choice = mocker.patch('cookiecutter.prompt.read_user_choice')
         read_user_choice.return_value = 'anewproject'
@@ -481,7 +484,9 @@ class TestPromptChoiceForConfig:
         """Fixture. Just populate context variable."""
         return {'cookiecutter': {'orientation': choices}}
 
-    def test_should_return_first_option_if_no_input(self, mocker, choices, context):
+    def test_should_return_first_option_if_no_input(
+        self, mocker, choices, context
+    ) -> None:
         """Verify prompt_choice_for_config return first list option on no_input=True."""
         read_user_choice = mocker.patch('cookiecutter.prompt.read_user_choice')
 
@@ -498,7 +503,7 @@ class TestPromptChoiceForConfig:
         assert not read_user_choice.called
         assert expected_choice == actual_choice
 
-    def test_should_read_user_choice(self, mocker, choices, context):
+    def test_should_read_user_choice(self, mocker, choices, context) -> None:
         """Verify prompt_choice_for_config return user selection on no_input=False."""
         read_user_choice = mocker.patch('cookiecutter.prompt.read_user_choice')
         read_user_choice.return_value = 'all'
@@ -515,8 +520,20 @@ class TestPromptChoiceForConfig:
         read_user_choice.assert_called_once_with('orientation', choices, None, '')
         assert expected_choice == actual_choice
 
+    def test_empty_list_returns_empty_string(self) -> None:
+        """Verify empty list returns empty string."""
+        context = {'project': 'foobar'}
+        with pytest.raises(ValueError):
+            prompt.prompt_choice_for_config(
+                cookiecutter_dict=context,
+                env=environment.StrictEnvironment(),
+                key='orientation',
+                options=[],
+                no_input=True,  # Suppress user input
+            )
 
-class TestReadUserYesNo(object):
+
+class TestReadUserYesNo:
     """Class to unite boolean prompt related tests."""
 
     @pytest.mark.parametrize(
@@ -526,7 +543,7 @@ class TestReadUserYesNo(object):
             False,
         ),
     )
-    def test_should_invoke_read_user_yes_no(self, mocker, run_as_docker):
+    def test_should_invoke_read_user_yes_no(self, mocker, run_as_docker) -> None:
         """Verify correct function called for boolean variables."""
         read_user_yes_no = mocker.patch('cookiecutter.prompt.read_user_yes_no')
         read_user_yes_no.return_value = run_as_docker
@@ -543,7 +560,7 @@ class TestReadUserYesNo(object):
         )
         assert cookiecutter_dict == {'run_as_docker': run_as_docker}
 
-    def test_boolean_parameter_no_input(self):
+    def test_boolean_parameter_no_input(self) -> None:
         """Verify boolean parameter sent to prompt for config with no input."""
         context = {
             'cookiecutter': {
@@ -569,7 +586,7 @@ class TestReadUserYesNo(object):
         'Undefined variable in cookiecutter dict with key_value',
     ],
 )
-def test_undefined_variable(context):
+def test_undefined_variable(context) -> None:
     """Verify `prompt.prompt_for_config` raises correct error."""
     with pytest.raises(exceptions.UndefinedVariableInTemplate) as err:
         prompt.prompt_for_config(context, no_input=True)
@@ -586,7 +603,7 @@ def test_undefined_variable(context):
         ["fake-nested-templates-old-style", "fake-package"],
     ],
 )
-def test_cookiecutter_nested_templates(template_dir: str, expected: str):
+def test_cookiecutter_nested_templates(template_dir: str, expected: Path | str) -> None:
     """Test nested_templates generation."""
     from cookiecutter import prompt
 
@@ -607,7 +624,7 @@ def test_cookiecutter_nested_templates(template_dir: str, expected: str):
         "/foo",
     ],
 )
-def test_cookiecutter_nested_templates_invalid_paths(path: str):
+def test_cookiecutter_nested_templates_invalid_paths(path: str) -> None:
     """Test nested_templates generation."""
     from cookiecutter import prompt
 
@@ -629,7 +646,7 @@ def test_cookiecutter_nested_templates_invalid_paths(path: str):
         "D:/tmp",
     ],
 )
-def test_cookiecutter_nested_templates_invalid_win_paths(path: str):
+def test_cookiecutter_nested_templates_invalid_win_paths(path: str) -> None:
     """Test nested_templates generation."""
     from cookiecutter import prompt
 
@@ -642,7 +659,7 @@ def test_cookiecutter_nested_templates_invalid_win_paths(path: str):
     assert "Illegal template path" in str(exc)
 
 
-def test_prompt_should_ask_and_rm_repo_dir(mocker, tmp_path):
+def test_prompt_should_ask_and_rm_repo_dir(mocker, tmp_path) -> None:
     """In `prompt_and_delete()`, if the user agrees to delete/reclone the \
     repo, the repo should be deleted."""
     mock_read_user = mocker.patch(
@@ -658,7 +675,7 @@ def test_prompt_should_ask_and_rm_repo_dir(mocker, tmp_path):
     assert deleted
 
 
-def test_prompt_should_ask_and_exit_on_user_no_answer(mocker, tmp_path):
+def test_prompt_should_ask_and_exit_on_user_no_answer(mocker, tmp_path) -> None:
     """In `prompt_and_delete()`, if the user decline to delete/reclone the \
     repo, cookiecutter should exit."""
     mock_read_user = mocker.patch(
@@ -677,7 +694,7 @@ def test_prompt_should_ask_and_exit_on_user_no_answer(mocker, tmp_path):
     assert mock_sys_exit.called
 
 
-def test_prompt_should_ask_and_rm_repo_file(mocker, tmp_path):
+def test_prompt_should_ask_and_rm_repo_file(mocker, tmp_path) -> None:
     """In `prompt_and_delete()`, if the user agrees to delete/reclone a \
     repo file, the repo should be deleted."""
     mock_read_user = mocker.patch(
@@ -694,7 +711,7 @@ def test_prompt_should_ask_and_rm_repo_file(mocker, tmp_path):
     assert deleted
 
 
-def test_prompt_should_ask_and_keep_repo_on_no_reuse(mocker, tmp_path):
+def test_prompt_should_ask_and_keep_repo_on_no_reuse(mocker, tmp_path) -> None:
     """In `prompt_and_delete()`, if the user wants to keep their old \
     cloned template repo, it should not be deleted."""
     mock_read_user = mocker.patch(
@@ -710,11 +727,11 @@ def test_prompt_should_ask_and_keep_repo_on_no_reuse(mocker, tmp_path):
     assert repo_dir.exists()
 
 
-def test_prompt_should_ask_and_keep_repo_on_reuse(mocker, tmp_path):
+def test_prompt_should_ask_and_keep_repo_on_reuse(mocker, tmp_path) -> None:
     """In `prompt_and_delete()`, if the user wants to keep their old \
     cloned template repo, it should not be deleted."""
 
-    def answer(question, default):
+    def answer(question, _default):
         return 'okay to delete' not in question
 
     mock_read_user = mocker.patch(
@@ -730,7 +747,7 @@ def test_prompt_should_ask_and_keep_repo_on_reuse(mocker, tmp_path):
     assert not deleted
 
 
-def test_prompt_should_not_ask_if_no_input_and_rm_repo_dir(mocker, tmp_path):
+def test_prompt_should_not_ask_if_no_input_and_rm_repo_dir(mocker, tmp_path) -> None:
     """Prompt should not ask if no input and rm dir.
 
     In `prompt_and_delete()`, if `no_input` is True, the call to
@@ -749,7 +766,7 @@ def test_prompt_should_not_ask_if_no_input_and_rm_repo_dir(mocker, tmp_path):
     assert deleted
 
 
-def test_prompt_should_not_ask_if_no_input_and_rm_repo_file(mocker, tmp_path):
+def test_prompt_should_not_ask_if_no_input_and_rm_repo_file(mocker, tmp_path) -> None:
     """Prompt should not ask if no input and rm file.
 
     In `prompt_and_delete()`, if `no_input` is True, the call to
