@@ -1,8 +1,9 @@
 """Tests around handling repositories which require authentication."""
+
 from cookiecutter.prompt import read_repo_password
 
 
-def test_click_invocation(mocker):
+def test_click_invocation(mocker) -> None:
     """Test click function called correctly by cookiecutter.
 
     Test for password (hidden input) type invocation.
