@@ -28,24 +28,24 @@ def template(tmp_path):
 
 
 @pytest.fixture(autouse=True)
-def mock_gen_context(mocker, context):
+def mock_gen_context(mocker, context) -> None:
     """Fixture. Automatically mock cookiecutter's function with expected output."""
     mocker.patch('cookiecutter.main.generate_context', return_value=context)
 
 
 @pytest.fixture(autouse=True)
-def mock_prompt(mocker):
+def mock_prompt(mocker) -> None:
     """Fixture. Automatically mock cookiecutter's function with expected output."""
     mocker.patch('cookiecutter.main.prompt_for_config')
 
 
 @pytest.fixture(autouse=True)
-def mock_replay(mocker):
+def mock_replay(mocker) -> None:
     """Fixture. Automatically mock cookiecutter's function with expected output."""
     mocker.patch('cookiecutter.main.dump')
 
 
-def test_api_invocation(mocker, template, output_dir, context):
+def test_api_invocation(mocker, template, output_dir, context) -> None:
     """Verify output dir location is correctly passed."""
     mock_gen_files = mocker.patch('cookiecutter.main.generate_files')
 
@@ -62,7 +62,7 @@ def test_api_invocation(mocker, template, output_dir, context):
     )
 
 
-def test_default_output_dir(mocker, template, context):
+def test_default_output_dir(mocker, template, context) -> None:
     """Verify default output dir is current working folder."""
     mock_gen_files = mocker.patch('cookiecutter.main.generate_files')
 
